# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Wrappers for protocol buffer enum types."""

import enum


class AvailabilitySignalType(enum.IntEnum):
    """
    The type of candidate availability signal.

    Attributes:
      AVAILABILITY_SIGNAL_TYPE_UNSPECIFIED (int): Default value.
      JOB_APPLICATION (int): Job application signal.

      In the context of ``Profile.availability_signals``, this signal is
      related to the candidate's most recent application. ``last_update_time``
      is calculated from max(\ ``Application.create_time``) from all
      ``Application`` records where ``Application.source`` is any of the
      following: ``APPLY_DIRECT_WEB`` ``APPLY_DIRECT_MOBILE_WEB``
      ``APPLY_DIRECT_MOBILE_APP`` ``APPLY_DIRECT_IN_PERSON``
      ``APPLY_INDIRECT``

      In the context of ``AvailabilityFilter``, the filter is applied on
      ``Profile.availability_signals`` where ``type`` is JOB\_APPLICATION.
      RESUME_UPDATE (int): Resume update signal.

      In the context of ``Profile.availability_signals``, this signal is
      related to the candidate's most recent update to their resume. For a
      ``SummarizedProfile.summary``, ``last_update_time`` is calculated from
      max(\ ``Profile.resume_update_time``) from all
      ``SummarizedProfile.profiles``.

      In the context of ``AvailabilityFilter``, the filter is applied on
      ``Profile.availability_signals`` where ``type`` is RESUME\_UPDATE.
      CANDIDATE_UPDATE (int): Candidate update signal.

      In the context of ``Profile.availability_signals``, this signal is
      related to the candidate's most recent update to their profile. For a
      ``SummarizedProfile.summary``, ``last_update_time`` is calculated from
      max(\ ``Profile.candidate_update_time``) from all
      ``SummarizedProfile.profiles``.

      In the context of ``AvailabilityFilter``, the filter is applied on
      ``Profile.availability_signals`` where ``type`` is CANDIDATE\_UPDATE.
      CLIENT_SUBMISSION (int): Client submission signal.

      In the context of ``Profile.availability_signals``, this signal is
      related to the candidate's most recent submission. ``last_update_time``
      is calculated from max(\ ``Application.create_time``) from all
      ``Application`` records where ``Application.stage`` is any of the
      following: ``HIRING_MANAGER_REVIEW`` ``INTERVIEW`` ``OFFER_EXTENDED``
      ``OFFER_ACCEPTED`` ``STARTED``

      In the context of ``AvailabilityFilter``, the filter is applied on
      ``Profile.availability_signals`` where ``type`` is CLIENT\_SUBMISSION.
    """

    AVAILABILITY_SIGNAL_TYPE_UNSPECIFIED = 0
    JOB_APPLICATION = 1
    RESUME_UPDATE = 2
    CANDIDATE_UPDATE = 3
    CLIENT_SUBMISSION = 4


class CommuteMethod(enum.IntEnum):
    """
    Method for commute.

    Attributes:
      COMMUTE_METHOD_UNSPECIFIED (int): Commute method isn't specified.
      DRIVING (int): Commute time is calculated based on driving time.
      TRANSIT (int): Commute time is calculated based on public transit including bus, metro,
      subway, and so on.
      WALKING (int): Commute time is calculated based on walking time.
      CYCLING (int): Commute time is calculated based on biking time.
    """

    COMMUTE_METHOD_UNSPECIFIED = 0
    DRIVING = 1
    TRANSIT = 2
    WALKING = 3
    CYCLING = 4


class CompanySize(enum.IntEnum):
    """
    An enum that represents the size of the company.

    Attributes:
      COMPANY_SIZE_UNSPECIFIED (int): Default value if the size isn't specified.
      MINI (int): The company has less than 50 employees.
      SMALL (int): The company has between 50 and 99 employees.
      SMEDIUM (int): The company has between 100 and 499 employees.
      MEDIUM (int): The company has between 500 and 999 employees.
      BIG (int): The company has between 1,000 and 4,999 employees.
      BIGGER (int): The company has between 5,000 and 9,999 employees.
      GIANT (int): The company has 10,000 or more employees.
    """

    COMPANY_SIZE_UNSPECIFIED = 0
    MINI = 1
    SMALL = 2
    SMEDIUM = 3
    MEDIUM = 4
    BIG = 5
    BIGGER = 6
    GIANT = 7


class ContactInfoUsage(enum.IntEnum):
    """
    Enum that represents the usage of the contact information.

    Attributes:
      CONTACT_INFO_USAGE_UNSPECIFIED (int): Default value.
      PERSONAL (int): Personal use.
      WORK (int): Work use.
      SCHOOL (int): School use.
    """

    CONTACT_INFO_USAGE_UNSPECIFIED = 0
    PERSONAL = 1
    WORK = 2
    SCHOOL = 3


class DegreeType(enum.IntEnum):
    """
    Educational degree level defined in International Standard Classification
    of Education (ISCED).

    Attributes:
      DEGREE_TYPE_UNSPECIFIED (int): Default value. Represents no degree, or early childhood education.
      Maps to ISCED code 0.
      Ex) Kindergarten
      PRIMARY_EDUCATION (int): Primary education which is typically the first stage of compulsory
      education. ISCED code 1.
      Ex) Elementary school
      LOWER_SECONDARY_EDUCATION (int): Lower secondary education; First stage of secondary education building on
      primary education, typically with a more subject-oriented curriculum.
      ISCED code 2.
      Ex) Middle school
      UPPER_SECONDARY_EDUCATION (int): Middle education; Second/final stage of secondary education preparing for
      tertiary education and/or providing skills relevant to employment.
      Usually with an increased range of subject options and streams. ISCED
      code 3.
      Ex) High school
      ADULT_REMEDIAL_EDUCATION (int): Adult Remedial Education; Programmes providing learning experiences that
      build on secondary education and prepare for labour market entry and/or
      tertiary education. The content is broader than secondary but not as
      complex as tertiary education. ISCED code 4.
      ASSOCIATES_OR_EQUIVALENT (int): Associate's or equivalent; Short first tertiary programmes that are
      typically practically-based, occupationally-specific and prepare for
      labour market entry. These programmes may also provide a pathway to other
      tertiary programmes. ISCED code 5.
      BACHELORS_OR_EQUIVALENT (int): Bachelor's or equivalent; Programmes designed to provide intermediate
      academic and/or professional knowledge, skills and competencies leading
      to a first tertiary degree or equivalent qualification. ISCED code 6.
      MASTERS_OR_EQUIVALENT (int): Master's or equivalent; Programmes designed to provide advanced academic
      and/or professional knowledge, skills and competencies leading to a
      second tertiary degree or equivalent qualification. ISCED code 7.
      DOCTORAL_OR_EQUIVALENT (int): Doctoral or equivalent; Programmes designed primarily to lead to an
      advanced research qualification, usually concluding with the submission
      and defense of a substantive dissertation of publishable quality based on
      original research. ISCED code 8.
    """

    DEGREE_TYPE_UNSPECIFIED = 0
    PRIMARY_EDUCATION = 1
    LOWER_SECONDARY_EDUCATION = 2
    UPPER_SECONDARY_EDUCATION = 3
    ADULT_REMEDIAL_EDUCATION = 4
    ASSOCIATES_OR_EQUIVALENT = 5
    BACHELORS_OR_EQUIVALENT = 6
    MASTERS_OR_EQUIVALENT = 7
    DOCTORAL_OR_EQUIVALENT = 8


class EmploymentType(enum.IntEnum):
    """
    An enum that represents the employment type of a job.

    Attributes:
      EMPLOYMENT_TYPE_UNSPECIFIED (int): The default value if the employment type isn't specified.
      FULL_TIME (int): The job requires working a number of hours that constitute full
      time employment, typically 40 or more hours per week.
      PART_TIME (int): The job entails working fewer hours than a full time job,
      typically less than 40 hours a week.
      CONTRACTOR (int): The job is offered as a contracted, as opposed to a salaried employee,
      position.
      CONTRACT_TO_HIRE (int): The job is offered as a contracted position with the understanding that
      it's converted into a full-time position at the end of the contract.
      Jobs of this type are also returned by a search for
      ``EmploymentType.CONTRACTOR`` jobs.
      TEMPORARY (int): The job is offered as a temporary employment opportunity, usually
      a short-term engagement.
      INTERN (int): The job is a fixed-term opportunity for students or entry-level job
      seekers to obtain on-the-job training, typically offered as a summer
      position.
      VOLUNTEER (int): The is an opportunity for an individual to volunteer, where there's no
      expectation of compensation for the provided services.
      PER_DIEM (int): The job requires an employee to work on an as-needed basis with a
      flexible schedule.
      FLY_IN_FLY_OUT (int): The job involves employing people in remote areas and flying them
      temporarily to the work site instead of relocating employees and their
      families permanently.
      OTHER_EMPLOYMENT_TYPE (int): The job does not fit any of the other listed types.
    """

    EMPLOYMENT_TYPE_UNSPECIFIED = 0
    FULL_TIME = 1
    PART_TIME = 2
    CONTRACTOR = 3
    CONTRACT_TO_HIRE = 4
    TEMPORARY = 5
    INTERN = 6
    VOLUNTEER = 7
    PER_DIEM = 8
    FLY_IN_FLY_OUT = 9
    OTHER_EMPLOYMENT_TYPE = 10


class HtmlSanitization(enum.IntEnum):
    """
    Option for HTML content sanitization on user input fields, for example, job
    description. By setting this option, user can determine whether and how
    sanitization is performed on these fields.

    Attributes:
      HTML_SANITIZATION_UNSPECIFIED (int): Default value.
      HTML_SANITIZATION_DISABLED (int): Disables sanitization on HTML input.
      SIMPLE_FORMATTING_ONLY (int): Sanitizes HTML input, only accepts bold, italic, ordered list, and
      unordered list markup tags.
    """

    HTML_SANITIZATION_UNSPECIFIED = 0
    HTML_SANITIZATION_DISABLED = 1
    SIMPLE_FORMATTING_ONLY = 2


class JobBenefit(enum.IntEnum):
    """
    An enum that represents employee benefits included with the job.

    Attributes:
      JOB_BENEFIT_UNSPECIFIED (int): Default value if the type isn't specified.
      CHILD_CARE (int): The job includes access to programs that support child care, such
      as daycare.
      DENTAL (int): The job includes dental services covered by a dental
      insurance plan.
      DOMESTIC_PARTNER (int): The job offers specific benefits to domestic partners.
      FLEXIBLE_HOURS (int): The job allows for a flexible work schedule.
      MEDICAL (int): The job includes health services covered by a medical insurance plan.
      LIFE_INSURANCE (int): The job includes a life insurance plan provided by the employer or
      available for purchase by the employee.
      PARENTAL_LEAVE (int): The job allows for a leave of absence to a parent to care for a newborn
      child.
      RETIREMENT_PLAN (int): The job includes a workplace retirement plan provided by the
      employer or available for purchase by the employee.
      SICK_DAYS (int): The job allows for paid time off due to illness.
      VACATION (int): The job includes paid time off for vacation.
      VISION (int): The job includes vision services covered by a vision
      insurance plan.
    """

    JOB_BENEFIT_UNSPECIFIED = 0
    CHILD_CARE = 1
    DENTAL = 2
    DOMESTIC_PARTNER = 3
    FLEXIBLE_HOURS = 4
    MEDICAL = 5
    LIFE_INSURANCE = 6
    PARENTAL_LEAVE = 7
    RETIREMENT_PLAN = 8
    SICK_DAYS = 9
    VACATION = 10
    VISION = 11


class JobCategory(enum.IntEnum):
    """
    An enum that represents the categorization or primary focus of specific
    role. This value is different than the "industry" associated with a role,
    which is related to the categorization of the company listing the job.

    Attributes:
      JOB_CATEGORY_UNSPECIFIED (int): The default value if the category isn't specified.
      ACCOUNTING_AND_FINANCE (int): An accounting and finance job, such as an Accountant.
      ADMINISTRATIVE_AND_OFFICE (int): An administrative and office job, such as an Administrative Assistant.
      ADVERTISING_AND_MARKETING (int): An advertising and marketing job, such as Marketing Manager.
      ANIMAL_CARE (int): An animal care job, such as Veterinarian.
      ART_FASHION_AND_DESIGN (int): An art, fashion, or design job, such as Designer.
      BUSINESS_OPERATIONS (int): A business operations job, such as Business Operations Manager.
      CLEANING_AND_FACILITIES (int): A cleaning and facilities job, such as Custodial Staff.
      COMPUTER_AND_IT (int): A computer and IT job, such as Systems Administrator.
      CONSTRUCTION (int): A construction job, such as General Laborer.
      CUSTOMER_SERVICE (int): A customer service job, such s Cashier.
      EDUCATION (int): An education job, such as School Teacher.
      ENTERTAINMENT_AND_TRAVEL (int): An entertainment and travel job, such as Flight Attendant.
      FARMING_AND_OUTDOORS (int): A farming or outdoor job, such as Park Ranger.
      HEALTHCARE (int): A healthcare job, such as Registered Nurse.
      HUMAN_RESOURCES (int): A human resources job, such as Human Resources Director.
      INSTALLATION_MAINTENANCE_AND_REPAIR (int): An installation, maintenance, or repair job, such as Electrician.
      LEGAL (int): A legal job, such as Law Clerk.
      MANAGEMENT (int): A management job, often used in conjunction with another category,
      such as Store Manager.
      MANUFACTURING_AND_WAREHOUSE (int): A manufacturing or warehouse job, such as Assembly Technician.
      MEDIA_COMMUNICATIONS_AND_WRITING (int): A media, communications, or writing job, such as Media Relations.
      OIL_GAS_AND_MINING (int): An oil, gas or mining job, such as Offshore Driller.
      PERSONAL_CARE_AND_SERVICES (int): A personal care and services job, such as Hair Stylist.
      PROTECTIVE_SERVICES (int): A protective services job, such as Security Guard.
      REAL_ESTATE (int): A real estate job, such as Buyer's Agent.
      RESTAURANT_AND_HOSPITALITY (int): A restaurant and hospitality job, such as Restaurant Server.
      SALES_AND_RETAIL (int): A sales and/or retail job, such Sales Associate.
      SCIENCE_AND_ENGINEERING (int): A science and engineering job, such as Lab Technician.
      SOCIAL_SERVICES_AND_NON_PROFIT (int): A social services or non-profit job, such as Case Worker.
      SPORTS_FITNESS_AND_RECREATION (int): A sports, fitness, or recreation job, such as Personal Trainer.
      TRANSPORTATION_AND_LOGISTICS (int): A transportation or logistics job, such as Truck Driver.
    """

    JOB_CATEGORY_UNSPECIFIED = 0
    ACCOUNTING_AND_FINANCE = 1
    ADMINISTRATIVE_AND_OFFICE = 2
    ADVERTISING_AND_MARKETING = 3
    ANIMAL_CARE = 4
    ART_FASHION_AND_DESIGN = 5
    BUSINESS_OPERATIONS = 6
    CLEANING_AND_FACILITIES = 7
    COMPUTER_AND_IT = 8
    CONSTRUCTION = 9
    CUSTOMER_SERVICE = 10
    EDUCATION = 11
    ENTERTAINMENT_AND_TRAVEL = 12
    FARMING_AND_OUTDOORS = 13
    HEALTHCARE = 14
    HUMAN_RESOURCES = 15
    INSTALLATION_MAINTENANCE_AND_REPAIR = 16
    LEGAL = 17
    MANAGEMENT = 18
    MANUFACTURING_AND_WAREHOUSE = 19
    MEDIA_COMMUNICATIONS_AND_WRITING = 20
    OIL_GAS_AND_MINING = 21
    PERSONAL_CARE_AND_SERVICES = 22
    PROTECTIVE_SERVICES = 23
    REAL_ESTATE = 24
    RESTAURANT_AND_HOSPITALITY = 25
    SALES_AND_RETAIL = 26
    SCIENCE_AND_ENGINEERING = 27
    SOCIAL_SERVICES_AND_NON_PROFIT = 28
    SPORTS_FITNESS_AND_RECREATION = 29
    TRANSPORTATION_AND_LOGISTICS = 30


class JobLevel(enum.IntEnum):
    """
    An enum that represents the required experience level required for the job.

    Attributes:
      JOB_LEVEL_UNSPECIFIED (int): The default value if the level isn't specified.
      ENTRY_LEVEL (int): Entry-level individual contributors, typically with less than 2 years of
      experience in a similar role. Includes interns.
      EXPERIENCED (int): Experienced individual contributors, typically with 2+ years of
      experience in a similar role.
      MANAGER (int): Entry- to mid-level managers responsible for managing a team of people.
      DIRECTOR (int): Senior-level managers responsible for managing teams of managers.
      EXECUTIVE (int): Executive-level managers and above, including C-level positions.
    """

    JOB_LEVEL_UNSPECIFIED = 0
    ENTRY_LEVEL = 1
    EXPERIENCED = 2
    MANAGER = 3
    DIRECTOR = 4
    EXECUTIVE = 5


class JobView(enum.IntEnum):
    """
    An enum that specifies the job attributes that are returned in the
    ``MatchingJob.job`` or ``ListJobsResponse.jobs`` fields.

    Attributes:
      JOB_VIEW_UNSPECIFIED (int): Default value.
      JOB_VIEW_ID_ONLY (int): A ID only view of job, with following attributes: ``Job.name``,
      ``Job.requisition_id``, ``Job.language_code``.
      JOB_VIEW_MINIMAL (int): A minimal view of the job, with the following attributes: ``Job.name``,
      ``Job.requisition_id``, ``Job.title``, ``Job.company``,
      ``Job.DerivedInfo.locations``, ``Job.language_code``.
      JOB_VIEW_SMALL (int): A small view of the job, with the following attributes in the search
      results: ``Job.name``, ``Job.requisition_id``, ``Job.title``,
      ``Job.company``, ``Job.DerivedInfo.locations``, ``Job.visibility``,
      ``Job.language_code``, ``Job.description``.
      JOB_VIEW_FULL (int): All available attributes are included in the search results.
    """

    JOB_VIEW_UNSPECIFIED = 0
    JOB_VIEW_ID_ONLY = 1
    JOB_VIEW_MINIMAL = 2
    JOB_VIEW_SMALL = 3
    JOB_VIEW_FULL = 4


class Outcome(enum.IntEnum):
    """
    The overall outcome /decision / result indicator.

    Attributes:
      OUTCOME_UNSPECIFIED (int): Default value.
      POSITIVE (int): A positive outcome / passing indicator (for example, candidate was
      recommended for hiring or to be moved forward in the hiring process,
      candidate passed a test).
      NEUTRAL (int): A neutral outcome / no clear indicator (for example, no strong
      reccommendation either to move forward / not move forward, neutral score).
      NEGATIVE (int): A negative outcome / failing indicator (for example, candidate was
      recommended to NOT move forward in the hiring process, failed a test).
      OUTCOME_NOT_AVAILABLE (int): The assessment outcome is not available or otherwise unknown (for example,
      candidate did not complete assessment).
    """

    OUTCOME_UNSPECIFIED = 0
    POSITIVE = 1
    NEUTRAL = 2
    NEGATIVE = 3
    OUTCOME_NOT_AVAILABLE = 4


class PostingRegion(enum.IntEnum):
    """
    An enum that represents the job posting region. In most cases, job postings
    don't need to specify a region. If a region is given, jobs are
    eligible for searches in the specified region.

    Attributes:
      POSTING_REGION_UNSPECIFIED (int): If the region is unspecified, the job is only returned if it matches the
      ``LocationFilter``.
      ADMINISTRATIVE_AREA (int): In addition to exact location matching, job posting is returned when the
      ``LocationFilter`` in the search query is in the same administrative
      area as the returned job posting. For example, if a
      ``ADMINISTRATIVE_AREA`` job is posted in "CA, USA", it's returned if
      ``LocationFilter`` has "Mountain View".

      Administrative area refers to top-level administrative subdivision of
      this country. For example, US state, IT region, UK constituent nation
      and JP prefecture.
      NATION (int): In addition to exact location matching, job is returned when
      ``LocationFilter`` in search query is in the same country as this job.
      For example, if a ``NATION_WIDE`` job is posted in "USA", it's returned
      if ``LocationFilter`` has 'Mountain View'.
      TELECOMMUTE (int): Job allows employees to work remotely (telecommute).
      If locations are provided with this value, the job is
      considered as having a location, but telecommuting is allowed.
    """

    POSTING_REGION_UNSPECIFIED = 0
    ADMINISTRATIVE_AREA = 1
    NATION = 2
    TELECOMMUTE = 3


class SkillProficiencyLevel(enum.IntEnum):
    """
    Enum that represents the skill proficiency level.

    Attributes:
      SKILL_PROFICIENCY_LEVEL_UNSPECIFIED (int): Default value.
      UNSKILLED (int): Lacks any proficiency in this skill.
      FUNDAMENTAL_AWARENESS (int): Have a common knowledge or an understanding of basic techniques and
      concepts.
      NOVICE (int): Have the level of experience gained in a classroom and/or experimental
      scenarios or as a trainee on-the-job.
      INTERMEDIATE (int): Be able to successfully complete tasks in this skill as requested. Help
      from an expert may be required from time to time, but can usually perform
      skill independently.
      ADVANCED (int): Can perform the actions associated with this skill without assistance.
      EXPERT (int): Known as an expert in this area.
    """

    SKILL_PROFICIENCY_LEVEL_UNSPECIFIED = 0
    UNSKILLED = 6
    FUNDAMENTAL_AWARENESS = 1
    NOVICE = 2
    INTERMEDIATE = 3
    ADVANCED = 4
    EXPERT = 5


class Visibility(enum.IntEnum):
    """
    Deprecated. All resources are only visible to the owner.

    An enum that represents who has view access to the resource.

    Attributes:
      VISIBILITY_UNSPECIFIED (int): Default value.
      ACCOUNT_ONLY (int): The resource is only visible to the GCP account who owns it.
      SHARED_WITH_GOOGLE (int): The resource is visible to the owner and may be visible to other
      applications and processes at Google.
      SHARED_WITH_PUBLIC (int): The resource is visible to the owner and may be visible to all other API
      clients.
    """

    VISIBILITY_UNSPECIFIED = 0
    ACCOUNT_ONLY = 1
    SHARED_WITH_GOOGLE = 2
    SHARED_WITH_PUBLIC = 3


class Application(object):
    class ApplicationStage(enum.IntEnum):
        """
        The stage of the application.

        Attributes:
          APPLICATION_STAGE_UNSPECIFIED (int): Default value.
          NEW (int): Candidate has applied or a recruiter put candidate into consideration but
          candidate is not yet screened / no decision has been made to move or not
          move the candidate to the next stage.
          SCREEN (int): A recruiter decided to screen the candidate for this role.
          HIRING_MANAGER_REVIEW (int): Candidate is being / was sent to the customer / hiring manager for
          detailed review.
          INTERVIEW (int): Candidate was approved by the client / hiring manager and is being / was
          interviewed for the role.
          OFFER_EXTENDED (int): Candidate will be / has been given an offer of employment.
          OFFER_ACCEPTED (int): Candidate has accepted their offer of employment.
          STARTED (int): Candidate has begun (or completed) their employment or assignment with
          the employer.
        """

        APPLICATION_STAGE_UNSPECIFIED = 0
        NEW = 1
        SCREEN = 2
        HIRING_MANAGER_REVIEW = 3
        INTERVIEW = 4
        OFFER_EXTENDED = 5
        OFFER_ACCEPTED = 6
        STARTED = 7

    class ApplicationState(enum.IntEnum):
        """
        Enum that represents the application status.

        Attributes:
          APPLICATION_STATE_UNSPECIFIED (int): Default value.
          IN_PROGRESS (int): The current stage is in progress or pending, for example, interviews in
          progress.
          CANDIDATE_WITHDREW (int): The current stage was terminated by a candidate decision.
          EMPLOYER_WITHDREW (int): The current stage was terminated by an employer or agency decision.
          COMPLETED (int): The current stage is successfully completed, but the next stage (if
          applicable) has not begun.
          CLOSED (int): The current stage was closed without an exception, or terminated for
          reasons unrealated to the candidate.
        """

        APPLICATION_STATE_UNSPECIFIED = 0
        IN_PROGRESS = 1
        CANDIDATE_WITHDREW = 2
        EMPLOYER_WITHDREW = 3
        COMPLETED = 4
        CLOSED = 5


class BatchOperationMetadata(object):
    class State(enum.IntEnum):
        """
        Attributes:
          STATE_UNSPECIFIED (int): Default value.
          INITIALIZING (int): The batch operation is being prepared for processing.
          PROCESSING (int): The batch operation is actively being processed.
          SUCCEEDED (int): The batch operation is processed, and at least one item has been
          successfully processed.
          FAILED (int): The batch operation is done and no item has been successfully processed.
          CANCELLING (int): The batch operation is in the process of cancelling after
          ``google.longrunning.Operations.CancelOperation`` is called.
          CANCELLED (int): The batch operation is done after
          ``google.longrunning.Operations.CancelOperation`` is called. Any items
          processed before cancelling are returned in the response.
        """

        STATE_UNSPECIFIED = 0
        INITIALIZING = 1
        PROCESSING = 2
        SUCCEEDED = 3
        FAILED = 4
        CANCELLING = 5
        CANCELLED = 6


class CommuteFilter(object):
    class RoadTraffic(enum.IntEnum):
        """
        The traffic density to use when calculating commute time.

        Attributes:
          ROAD_TRAFFIC_UNSPECIFIED (int): Road traffic situation isn't specified.
          TRAFFIC_FREE (int): Optimal commute time without considering any traffic impact.
          BUSY_HOUR (int): Commute time calculation takes in account the peak traffic impact.
        """

        ROAD_TRAFFIC_UNSPECIFIED = 0
        TRAFFIC_FREE = 1
        BUSY_HOUR = 2


class CompensationFilter(object):
    class FilterType(enum.IntEnum):
        """
        Specify the type of filtering.

        Attributes:
          FILTER_TYPE_UNSPECIFIED (int): Filter type unspecified. Position holder, INVALID, should never be used.
          UNIT_ONLY (int): Filter by ``base compensation entry's`` unit. A job is a match if and
          only if the job contains a base CompensationEntry and the base
          CompensationEntry's unit matches provided ``units``. Populate one or
          more ``units``.

          See ``CompensationInfo.CompensationEntry`` for definition of base
          compensation entry.
          UNIT_AND_AMOUNT (int): Filter by ``base compensation entry's`` unit and amount / range. A job
          is a match if and only if the job contains a base CompensationEntry, and
          the base entry's unit matches provided ``CompensationUnit`` and amount
          or range overlaps with provided ``CompensationRange``.

          See ``CompensationInfo.CompensationEntry`` for definition of base
          compensation entry.

          Set exactly one ``units`` and populate ``range``.
          ANNUALIZED_BASE_AMOUNT (int): Filter by annualized base compensation amount and
          ``base compensation entry's`` unit. Populate ``range`` and zero or more
          ``units``.
          ANNUALIZED_TOTAL_AMOUNT (int): Filter by annualized total compensation amount and
          ``base compensation entry's`` unit . Populate ``range`` and zero or more
          ``units``.
        """

        FILTER_TYPE_UNSPECIFIED = 0
        UNIT_ONLY = 1
        UNIT_AND_AMOUNT = 2
        ANNUALIZED_BASE_AMOUNT = 3
        ANNUALIZED_TOTAL_AMOUNT = 4


class CompensationInfo(object):
    class CompensationType(enum.IntEnum):
        """
        The type of compensation.

        For compensation amounts specified in non-monetary amounts, describe the
        compensation scheme in the ``CompensationEntry.description``.

        For example, tipping format is described in
        ``CompensationEntry.description`` (for example, "expect 15-20% tips
        based on customer bill.") and an estimate of the tips provided in
        ``CompensationEntry.amount`` or ``CompensationEntry.range`` ($10 per
        hour).

        For example, equity is described in ``CompensationEntry.description``
        (for example, "1% - 2% equity vesting over 4 years, 1 year cliff") and
        value estimated in ``CompensationEntry.amount`` or
        ``CompensationEntry.range``. If no value estimate is possible, units are
        ``CompensationUnit.COMPENSATION_UNIT_UNSPECIFIED`` and then further
        clarified in ``CompensationEntry.description`` field.

        Attributes:
          COMPENSATION_TYPE_UNSPECIFIED (int): Default value.
          BASE (int): Base compensation: Refers to the fixed amount of money paid to an
          employee by an employer in return for work performed. Base compensation
          does not include benefits, bonuses or any other potential compensation
          from an employer.
          BONUS (int): Bonus.
          SIGNING_BONUS (int): Signing bonus.
          EQUITY (int): Equity.
          PROFIT_SHARING (int): Profit sharing.
          COMMISSIONS (int): Commission.
          TIPS (int): Tips.
          OTHER_COMPENSATION_TYPE (int): Other compensation type.
        """

        COMPENSATION_TYPE_UNSPECIFIED = 0
        BASE = 1
        BONUS = 2
        SIGNING_BONUS = 3
        EQUITY = 4
        PROFIT_SHARING = 5
        COMMISSIONS = 6
        TIPS = 7
        OTHER_COMPENSATION_TYPE = 8

    class CompensationUnit(enum.IntEnum):
        """
        Pay frequency.

        Attributes:
          COMPENSATION_UNIT_UNSPECIFIED (int): Default value.
          HOURLY (int): Hourly.
          DAILY (int): Daily.
          WEEKLY (int): Weekly
          MONTHLY (int): Monthly.
          YEARLY (int): Yearly.
          ONE_TIME (int): One time.
          OTHER_COMPENSATION_UNIT (int): Other compensation units.
        """

        COMPENSATION_UNIT_UNSPECIFIED = 0
        HOURLY = 1
        DAILY = 2
        WEEKLY = 3
        MONTHLY = 4
        YEARLY = 5
        ONE_TIME = 6
        OTHER_COMPENSATION_UNIT = 7


class CompleteQueryRequest(object):
    class CompletionScope(enum.IntEnum):
        """
        Enum to specify the scope of completion.

        Attributes:
          COMPLETION_SCOPE_UNSPECIFIED (int): Default value.
          TENANT (int): Suggestions are based only on the data provided by the client.
          PUBLIC (int): Suggestions are based on all jobs data in the system that's visible to
          the client
        """

        COMPLETION_SCOPE_UNSPECIFIED = 0
        TENANT = 1
        PUBLIC = 2

    class CompletionType(enum.IntEnum):
        """
        Enum to specify auto-completion topics.

        Attributes:
          COMPLETION_TYPE_UNSPECIFIED (int): Default value.
          JOB_TITLE (int): Suggest job titles for jobs autocomplete.

          For ``CompletionType.JOB_TITLE`` type, only open jobs with the same
          ``language_codes`` are returned.
          COMPANY_NAME (int): Suggest company names for jobs autocomplete.

          For ``CompletionType.COMPANY_NAME`` type, only companies having open
          jobs with the same ``language_codes`` are returned.
          COMBINED (int): Suggest both job titles and company names for jobs autocomplete.

          For ``CompletionType.COMBINED`` type, only open jobs with the same
          ``language_codes`` or companies having open jobs with the same
          ``language_codes`` are returned.
        """

        COMPLETION_TYPE_UNSPECIFIED = 0
        JOB_TITLE = 1
        COMPANY_NAME = 2
        COMBINED = 3


class DeviceInfo(object):
    class DeviceType(enum.IntEnum):
        """
        An enumeration describing an API access portal and exposure mechanism.

        Attributes:
          DEVICE_TYPE_UNSPECIFIED (int): The device type isn't specified.
          WEB (int): A desktop web browser, such as, Chrome, Firefox, Safari, or Internet
          Explorer)
          MOBILE_WEB (int): A mobile device web browser, such as a phone or tablet with a Chrome
          browser.
          ANDROID (int): An Android device native application.
          IOS (int): An iOS device native application.
          BOT (int): A bot, as opposed to a device operated by human beings, such as a web
          crawler.
          OTHER (int): Other devices types.
        """

        DEVICE_TYPE_UNSPECIFIED = 0
        WEB = 1
        MOBILE_WEB = 2
        ANDROID = 3
        IOS = 4
        BOT = 5
        OTHER = 6


class EmployerFilter(object):
    class EmployerFilterMode(enum.IntEnum):
        """
        Enum indicating which set of ``Profile.employment_records`` to search
        against.

        Attributes:
          EMPLOYER_FILTER_MODE_UNSPECIFIED (int): Default value.
          ALL_EMPLOYMENT_RECORDS (int): Apply to all employers in ``Profile.employment_records``.
          CURRENT_EMPLOYMENT_RECORDS_ONLY (int): Apply only to current employer in ``Profile.employment_records``.
          PAST_EMPLOYMENT_RECORDS_ONLY (int): Apply only to past (not current) employers in
          ``Profile.employment_records``.
        """

        EMPLOYER_FILTER_MODE_UNSPECIFIED = 0
        ALL_EMPLOYMENT_RECORDS = 1
        CURRENT_EMPLOYMENT_RECORDS_ONLY = 2
        PAST_EMPLOYMENT_RECORDS_ONLY = 3


class JobEvent(object):
    class JobEventType(enum.IntEnum):
        """
        An enumeration of an event attributed to the behavior of the end user,
        such as a job seeker.

        Attributes:
          JOB_EVENT_TYPE_UNSPECIFIED (int): The event is unspecified by other provided values.
          IMPRESSION (int): The job seeker or other entity interacting with the service has
          had a job rendered in their view, such as in a list of search results in
          a compressed or clipped format. This event is typically associated with
          the viewing of a jobs list on a single page by a job seeker.
          VIEW (int): The job seeker, or other entity interacting with the service, has viewed
          the details of a job, including the full description. This event doesn't
          apply to the viewing a snippet of a job appearing as a part of the job
          search results. Viewing a snippet is associated with an ``impression``).
          VIEW_REDIRECT (int): The job seeker or other entity interacting with the service
          performed an action to view a job and was redirected to a different
          website for job.
          APPLICATION_START (int): The job seeker or other entity interacting with the service
          began the process or demonstrated the intention of applying for a job.
          APPLICATION_FINISH (int): The job seeker or other entity interacting with the service
          submitted an application for a job.
          APPLICATION_QUICK_SUBMISSION (int): The job seeker or other entity interacting with the service submitted an
          application for a job with a single click without entering information.
          If a job seeker performs this action, send only this event to the
          service. Do not also send ``JobEventType.APPLICATION_START`` or
          ``JobEventType.APPLICATION_FINISH`` events.
          APPLICATION_REDIRECT (int): The job seeker or other entity interacting with the service
          performed an action to apply to a job and was redirected to a different
          website to complete the application.
          APPLICATION_START_FROM_SEARCH (int): The job seeker or other entity interacting with the service began the
          process or demonstrated the intention of applying for a job from the
          search results page without viewing the details of the job posting.
          If sending this event, JobEventType.VIEW event shouldn't be sent.
          APPLICATION_REDIRECT_FROM_SEARCH (int): The job seeker, or other entity interacting with the service, performs
          an action with a single click from the search results page to apply to a
          job (without viewing the details of the job posting), and is redirected
          to a different website to complete the application. If a candidate
          performs this action, send only this event to the service. Do not also
          send ``JobEventType.APPLICATION_START``,
          ``JobEventType.APPLICATION_FINISH`` or ``JobEventType.VIEW`` events.
          APPLICATION_COMPANY_SUBMIT (int): This event should be used when a company submits an application
          on behalf of a job seeker. This event is intended for use by staffing
          agencies attempting to place candidates.
          BOOKMARK (int): The job seeker or other entity interacting with the service demonstrated
          an interest in a job by bookmarking or saving it.
          NOTIFICATION (int): The job seeker or other entity interacting with the service was
          sent a notification, such as an email alert or device notification,
          containing one or more jobs listings generated by the service.
          HIRED (int): The job seeker or other entity interacting with the service was
          employed by the hiring entity (employer). Send this event
          only if the job seeker was hired through an application that was
          initiated by a search conducted through the Cloud Talent Solution
          service.
          SENT_CV (int): A recruiter or staffing agency submitted an application on behalf of the
          candidate after interacting with the service to identify a suitable job
          posting.
          INTERVIEW_GRANTED (int): The entity interacting with the service (for example, the job seeker),
          was granted an initial interview by the hiring entity (employer). This
          event should only be sent if the job seeker was granted an interview as
          part of an application that was initiated by a search conducted through /
          recommendation provided by the Cloud Talent Solution service.
        """

        JOB_EVENT_TYPE_UNSPECIFIED = 0
        IMPRESSION = 1
        VIEW = 2
        VIEW_REDIRECT = 3
        APPLICATION_START = 4
        APPLICATION_FINISH = 5
        APPLICATION_QUICK_SUBMISSION = 6
        APPLICATION_REDIRECT = 7
        APPLICATION_START_FROM_SEARCH = 8
        APPLICATION_REDIRECT_FROM_SEARCH = 9
        APPLICATION_COMPANY_SUBMIT = 10
        BOOKMARK = 11
        NOTIFICATION = 12
        HIRED = 13
        SENT_CV = 14
        INTERVIEW_GRANTED = 15


class Location(object):
    class LocationType(enum.IntEnum):
        """
        An enum which represents the type of a location.

        Attributes:
          LOCATION_TYPE_UNSPECIFIED (int): Default value if the type isn't specified.
          COUNTRY (int): A country level location.
          ADMINISTRATIVE_AREA (int): A state or equivalent level location.
          SUB_ADMINISTRATIVE_AREA (int): A county or equivalent level location.
          LOCALITY (int): A city or equivalent level location.
          POSTAL_CODE (int): A postal code level location.
          SUB_LOCALITY (int): A sublocality is a subdivision of a locality, for example a city borough,
          ward, or arrondissement. Sublocalities are usually recognized by a local
          political authority. For example, Manhattan and Brooklyn are recognized
          as boroughs by the City of New York, and are therefore modeled as
          sublocalities.
          SUB_LOCALITY_1 (int): A district or equivalent level location.
          SUB_LOCALITY_2 (int): A smaller district or equivalent level display.
          NEIGHBORHOOD (int): A neighborhood level location.
          STREET_ADDRESS (int): A street address level location.
        """

        LOCATION_TYPE_UNSPECIFIED = 0
        COUNTRY = 1
        ADMINISTRATIVE_AREA = 2
        SUB_ADMINISTRATIVE_AREA = 3
        LOCALITY = 4
        POSTAL_CODE = 5
        SUB_LOCALITY = 6
        SUB_LOCALITY_1 = 7
        SUB_LOCALITY_2 = 8
        NEIGHBORHOOD = 9
        STREET_ADDRESS = 10


class LocationFilter(object):
    class TelecommutePreference(enum.IntEnum):
        """
        Specify whether to include telecommute jobs.

        Attributes:
          TELECOMMUTE_PREFERENCE_UNSPECIFIED (int): Default value if the telecommute preference isn't specified.
          TELECOMMUTE_EXCLUDED (int): Exclude telecommute jobs.
          TELECOMMUTE_ALLOWED (int): Allow telecommute jobs.
        """

        TELECOMMUTE_PREFERENCE_UNSPECIFIED = 0
        TELECOMMUTE_EXCLUDED = 1
        TELECOMMUTE_ALLOWED = 2


class Phone(object):
    class PhoneType(enum.IntEnum):
        """
        Enum that represents the type of the telephone.

        Attributes:
          PHONE_TYPE_UNSPECIFIED (int): Default value.
          LANDLINE (int): A landline.
          MOBILE (int): A mobile.
          FAX (int): A fax.
          PAGER (int): A pager.
          TTY_OR_TDD (int): A TTY (test telephone) or TDD (telecommunication device for the deaf).
          VOICEMAIL (int): A voicemail.
          VIRTUAL (int): A virtual telephone number is a number that can be routed to another
          number and managed by the user via Web, SMS, IVR, and so on. It is
          associated with a particular person, and may be routed to either a
          MOBILE or LANDLINE number. The ``phone usage`` should be set to PERSONAL
          for these phone types. Some more information can be found here:
          https://en.wikipedia.org/wiki/Personal\_Numbers
          VOIP (int): Voice over IP numbers. This includes TSoIP (Telephony Service over IP).
          MOBILE_OR_LANDLINE (int): In some regions (e.g. the USA), it is impossible to distinguish between
          fixed-line and mobile numbers by looking at the phone number itself.
        """

        PHONE_TYPE_UNSPECIFIED = 0
        LANDLINE = 1
        MOBILE = 2
        FAX = 3
        PAGER = 4
        TTY_OR_TDD = 5
        VOICEMAIL = 6
        VIRTUAL = 7
        VOIP = 8
        MOBILE_OR_LANDLINE = 9


class ProfileEvent(object):
    class ProfileEventType(enum.IntEnum):
        """
        The enum represents types of client events for a candidate profile.

        Attributes:
          PROFILE_EVENT_TYPE_UNSPECIFIED (int): Default value.
          IMPRESSION (int): Send this event when a ``ProfileEvent.profiles`` was sent as a part of a
          result set for a CTS API call and was rendered in the end user's UI
          (that is, the ``ProfileEvent.recruiter``).
          VIEW (int): The VIEW event records the action of a candidate's profile being viewed
          by an end user. This is critical to tracking product metrics and should
          be sent for every profile VIEW that happens in your system, whether the
          event is associated with an API call (for example, a recruiter making a
          request for a result set and clicking on a profile) or not (a recruiter
          using the system to view profile details without making a request).

          For a VIEW events associated with API calls, the
          ``ClientEvent.request_id`` should be populated. If the VIEW is not
          associated with an API call, ``request_id`` should not be populated.

          This event requires a valid recruiter and one valid ID in profiles.
          BOOKMARK (int): The profile is bookmarked.
        """

        PROFILE_EVENT_TYPE_UNSPECIFIED = 0
        IMPRESSION = 1
        VIEW = 2
        BOOKMARK = 3


class Resume(object):
    class ResumeType(enum.IntEnum):
        """
        The format of a structured resume.

        Attributes:
          RESUME_TYPE_UNSPECIFIED (int): Default value.
          HRXML (int): The profile contents in HR-XML format.
          See https://schemas.liquid-technologies.com/hr-xml/2007-04-15/ for more
          information about Human Resources XML.
          OTHER_RESUME_TYPE (int): Resume type not specified.
        """

        RESUME_TYPE_UNSPECIFIED = 0
        HRXML = 1
        OTHER_RESUME_TYPE = 2


class SearchJobsRequest(object):
    class DiversificationLevel(enum.IntEnum):
        """
        Controls whether highly similar jobs are returned next to each other in
        the search results. Jobs are identified as highly similar based on
        their titles, job categories, and locations. Highly similar results are
        clustered so that only one representative job of the cluster is
        displayed to the job seeker higher up in the results, with the other jobs
        being displayed lower down in the results.

        Attributes:
          DIVERSIFICATION_LEVEL_UNSPECIFIED (int): The diversification level isn't specified.
          DISABLED (int): Disables diversification. Jobs that would normally be pushed to the last
          page would not have their positions altered. This may result in highly
          similar jobs appearing in sequence in the search results.
          SIMPLE (int): Default diversifying behavior. The result list is ordered so that
          highly similar results are pushed to the end of the last page of search
          results. If you are using pageToken to page through the result set,
          latency might be lower but we can't guarantee that all results are
          returned. If you are using page offset, latency might be higher but all
          results are returned.
        """

        DIVERSIFICATION_LEVEL_UNSPECIFIED = 0
        DISABLED = 1
        SIMPLE = 2

    class SearchMode(enum.IntEnum):
        """
        A string-represented enumeration of the job search mode. The service
        operate differently for different modes of service.

        Attributes:
          SEARCH_MODE_UNSPECIFIED (int): The mode of the search method isn't specified. The default search
          behavior is identical to JOB\_SEARCH search behavior.
          JOB_SEARCH (int): The job search matches against all jobs, and featured jobs
          (jobs with promotionValue > 0) are not specially handled.
          FEATURED_JOB_SEARCH (int): The job search matches only against featured jobs (jobs with a
          promotionValue > 0). This method doesn't return any jobs having a
          promotionValue <= 0. The search results order is determined by the
          promotionValue (jobs with a higher promotionValue are returned higher up
          in the search results), with relevance being used as a tiebreaker.
        """

        SEARCH_MODE_UNSPECIFIED = 0
        JOB_SEARCH = 1
        FEATURED_JOB_SEARCH = 2

    class CustomRankingInfo(object):
        class ImportanceLevel(enum.IntEnum):
            """
            The importance level for ``CustomRankingInfo.ranking_expression``.

            Attributes:
              IMPORTANCE_LEVEL_UNSPECIFIED (int): Default value if the importance level isn't specified.
              NONE (int): The given ranking expression is of None importance, existing relevance
              score (determined by API algorithm) dominates job's final ranking
              position.
              LOW (int): The given ranking expression is of Low importance in terms of job's
              final ranking position compared to existing relevance
              score (determined by API algorithm).
              MILD (int): The given ranking expression is of Mild importance in terms of job's
              final ranking position compared to existing relevance
              score (determined by API algorithm).
              MEDIUM (int): The given ranking expression is of Medium importance in terms of job's
              final ranking position compared to existing relevance
              score (determined by API algorithm).
              HIGH (int): The given ranking expression is of High importance in terms of job's
              final ranking position compared to existing relevance
              score (determined by API algorithm).
              EXTREME (int): The given ranking expression is of Extreme importance, and dominates
              job's final ranking position with existing relevance
              score (determined by API algorithm) ignored.
            """

            IMPORTANCE_LEVEL_UNSPECIFIED = 0
            NONE = 1
            LOW = 2
            MILD = 3
            MEDIUM = 4
            HIGH = 5
            EXTREME = 6


class Tenant(object):
    class DataUsageType(enum.IntEnum):
        """
        Enum that represents how user data owned by the tenant is used.

        Attributes:
          DATA_USAGE_TYPE_UNSPECIFIED (int): Default value.
          AGGREGATED (int): Data owned by this tenant is used to improve search/recommendation
          quality across tenants.
          ISOLATED (int): Data owned by this tenant is used to improve search/recommendation
          quality for this tenant only.
        """

        DATA_USAGE_TYPE_UNSPECIFIED = 0
        AGGREGATED = 1
        ISOLATED = 2


class TimeFilter(object):
    class TimeField(enum.IntEnum):
        """
        Time fields can be used in TimeFilter.

        Attributes:
          TIME_FIELD_UNSPECIFIED (int): Default value.
          CREATE_TIME (int): Earliest profile create time.
          UPDATE_TIME (int): Latest profile update time.
        """

        TIME_FIELD_UNSPECIFIED = 0
        CREATE_TIME = 1
        UPDATE_TIME = 2



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import google.api_core.grpc_helpers
import google.api_core.operations_v1

from google.cloud.talent_v4beta1.proto import job_service_pb2_grpc


class JobServiceGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.cloud.talent.v4beta1 JobService API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """

    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = (
        "https://www.googleapis.com/auth/cloud-platform",
        "https://www.googleapis.com/auth/jobs",
    )

    def __init__(
        self, channel=None, credentials=None, address="jobs.googleapis.com:443"
    ):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                "The `channel` and `credentials` arguments are mutually " "exclusive."
            )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(
                address=address,
                credentials=credentials,
                options={
                    "grpc.max_send_message_length": -1,
                    "grpc.max_receive_message_length": -1,
                }.items(),
            )

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {"job_service_stub": job_service_pb2_grpc.JobServiceStub(channel)}

        # Because this API includes a method that returns a
        # long-running operation (proto: google.longrunning.Operation),
        # instantiate an LRO client.
        self._operations_client = google.api_core.operations_v1.OperationsClient(
            channel
        )

    @classmethod
    def create_channel(
        cls, address="jobs.googleapis.com:443", credentials=None, **kwargs
    ):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            kwargs (dict): Keyword arguments, which are passed to the
                channel creation.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address, credentials=credentials, scopes=cls._OAUTH_SCOPES, **kwargs
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def create_job(self):
        """Return the gRPC stub for :meth:`JobServiceClient.create_job`.

        Creates a new job.

        Typically, the job becomes searchable within 10 seconds, but it may take
        up to 5 minutes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].CreateJob

    @property
    def get_job(self):
        """Return the gRPC stub for :meth:`JobServiceClient.get_job`.

        Retrieves the specified job, whose status is OPEN or recently EXPIRED
        within the last 90 days.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].GetJob

    @property
    def update_job(self):
        """Return the gRPC stub for :meth:`JobServiceClient.update_job`.

        Updates specified job.

        Typically, updated contents become visible in search results within 10
        seconds, but it may take up to 5 minutes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].UpdateJob

    @property
    def delete_job(self):
        """Return the gRPC stub for :meth:`JobServiceClient.delete_job`.

        Deletes the specified job.

        Typically, the job becomes unsearchable within 10 seconds, but it may take
        up to 5 minutes.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].DeleteJob

    @property
    def list_jobs(self):
        """Return the gRPC stub for :meth:`JobServiceClient.list_jobs`.

        Lists jobs by filter.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].ListJobs

    @property
    def batch_delete_jobs(self):
        """Return the gRPC stub for :meth:`JobServiceClient.batch_delete_jobs`.

        Deletes a list of ``Job``\ s by filter.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].BatchDeleteJobs

    @property
    def search_jobs(self):
        """Return the gRPC stub for :meth:`JobServiceClient.search_jobs`.

        Searches for jobs using the provided ``SearchJobsRequest``.

        This call constrains the ``visibility`` of jobs present in the database,
        and only returns jobs that the caller has permission to search against.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].SearchJobs

    @property
    def search_jobs_for_alert(self):
        """Return the gRPC stub for :meth:`JobServiceClient.search_jobs_for_alert`.

        Searches for jobs using the provided ``SearchJobsRequest``.

        This API call is intended for the use case of targeting passive job
        seekers (for example, job seekers who have signed up to receive email
        alerts about potential job opportunities), and has different algorithmic
        adjustments that are targeted to passive job seekers.

        This call constrains the ``visibility`` of jobs present in the database,
        and only returns jobs the caller has permission to search against.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].SearchJobsForAlert

    @property
    def batch_create_jobs(self):
        """Return the gRPC stub for :meth:`JobServiceClient.batch_create_jobs`.

        Begins executing a batch create jobs operation.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].BatchCreateJobs

    @property
    def batch_update_jobs(self):
        """Return the gRPC stub for :meth:`JobServiceClient.batch_update_jobs`.

        Begins executing a batch update jobs operation.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["job_service_stub"].BatchUpdateJobs



config = {
    "interfaces": {
        "google.cloud.talent.v4beta1.TenantService": {
            "retry_codes": {
                "idempotent": ["DEADLINE_EXCEEDED", "UNAVAILABLE"],
                "non_idempotent": [],
            },
            "retry_params": {
                "default": {
                    "initial_retry_delay_millis": 100,
                    "retry_delay_multiplier": 1.3,
                    "max_retry_delay_millis": 60000,
                    "initial_rpc_timeout_millis": 20000,
                    "rpc_timeout_multiplier": 1.0,
                    "max_rpc_timeout_millis": 20000,
                    "total_timeout_millis": 300000,
                }
            },
            "methods": {
                "CreateTenant": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetTenant": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "UpdateTenant": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "DeleteTenant": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "ListTenants": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
            },
        }
    }
}



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

from google.cloud import talent_v4beta1
from google.cloud.talent_v4beta1.proto import company_pb2
from google.cloud.talent_v4beta1.proto import company_service_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestCompanyServiceClient(object):
    def test_create_company(self):
        # Setup Expected Response
        name = "name3373707"
        display_name = "displayName1615086568"
        external_id = "externalId-1153075697"
        headquarters_address = "headquartersAddress-1879520036"
        hiring_agency = False
        eeo_text = "eeoText-1652097123"
        website_uri = "websiteUri-2118185016"
        career_site_uri = "careerSiteUri1223331861"
        image_uri = "imageUri-877823864"
        suspended = False
        expected_response = {
            "name": name,
            "display_name": display_name,
            "external_id": external_id,
            "headquarters_address": headquarters_address,
            "hiring_agency": hiring_agency,
            "eeo_text": eeo_text,
            "website_uri": website_uri,
            "career_site_uri": career_site_uri,
            "image_uri": image_uri,
            "suspended": suspended,
        }
        expected_response = company_pb2.Company(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        company = {}

        response = client.create_company(parent, company)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = company_service_pb2.CreateCompanyRequest(
            parent=parent, company=company
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_company_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        company = {}

        with pytest.raises(CustomException):
            client.create_company(parent, company)

    def test_get_company(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        display_name = "displayName1615086568"
        external_id = "externalId-1153075697"
        headquarters_address = "headquartersAddress-1879520036"
        hiring_agency = False
        eeo_text = "eeoText-1652097123"
        website_uri = "websiteUri-2118185016"
        career_site_uri = "careerSiteUri1223331861"
        image_uri = "imageUri-877823864"
        suspended = False
        expected_response = {
            "name": name_2,
            "display_name": display_name,
            "external_id": external_id,
            "headquarters_address": headquarters_address,
            "hiring_agency": hiring_agency,
            "eeo_text": eeo_text,
            "website_uri": website_uri,
            "career_site_uri": career_site_uri,
            "image_uri": image_uri,
            "suspended": suspended,
        }
        expected_response = company_pb2.Company(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup Request
        name = client.company_path("[PROJECT]", "[TENANT]", "[COMPANY]")

        response = client.get_company(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = company_service_pb2.GetCompanyRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_company_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup request
        name = client.company_path("[PROJECT]", "[TENANT]", "[COMPANY]")

        with pytest.raises(CustomException):
            client.get_company(name)

    def test_update_company(self):
        # Setup Expected Response
        name = "name3373707"
        display_name = "displayName1615086568"
        external_id = "externalId-1153075697"
        headquarters_address = "headquartersAddress-1879520036"
        hiring_agency = False
        eeo_text = "eeoText-1652097123"
        website_uri = "websiteUri-2118185016"
        career_site_uri = "careerSiteUri1223331861"
        image_uri = "imageUri-877823864"
        suspended = False
        expected_response = {
            "name": name,
            "display_name": display_name,
            "external_id": external_id,
            "headquarters_address": headquarters_address,
            "hiring_agency": hiring_agency,
            "eeo_text": eeo_text,
            "website_uri": website_uri,
            "career_site_uri": career_site_uri,
            "image_uri": image_uri,
            "suspended": suspended,
        }
        expected_response = company_pb2.Company(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup Request
        company = {}

        response = client.update_company(company)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = company_service_pb2.UpdateCompanyRequest(company=company)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_company_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup request
        company = {}

        with pytest.raises(CustomException):
            client.update_company(company)

    def test_delete_company(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup Request
        name = client.company_path("[PROJECT]", "[TENANT]", "[COMPANY]")

        client.delete_company(name)

        assert len(channel.requests) == 1
        expected_request = company_service_pb2.DeleteCompanyRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_company_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup request
        name = client.company_path("[PROJECT]", "[TENANT]", "[COMPANY]")

        with pytest.raises(CustomException):
            client.delete_company(name)

    def test_list_companies(self):
        # Setup Expected Response
        next_page_token = ""
        companies_element = {}
        companies = [companies_element]
        expected_response = {"next_page_token": next_page_token, "companies": companies}
        expected_response = company_service_pb2.ListCompaniesResponse(
            **expected_response
        )

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")

        paged_list_response = client.list_companies(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.companies[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = company_service_pb2.ListCompaniesRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_companies_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.CompanyServiceClient()

        # Setup request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")

        paged_list_response = client.list_companies(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Accesses the google.cloud.talent.v4beta1 ProfileService API."""

import functools
import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.client_options
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.gapic_v1.routing_header
import google.api_core.grpc_helpers
import google.api_core.page_iterator
import google.api_core.path_template
import grpc

from google.cloud.talent_v4beta1.gapic import enums
from google.cloud.talent_v4beta1.gapic import profile_service_client_config
from google.cloud.talent_v4beta1.gapic.transports import profile_service_grpc_transport
from google.cloud.talent_v4beta1.proto import application_pb2
from google.cloud.talent_v4beta1.proto import application_service_pb2
from google.cloud.talent_v4beta1.proto import application_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import common_pb2
from google.cloud.talent_v4beta1.proto import company_pb2
from google.cloud.talent_v4beta1.proto import company_service_pb2
from google.cloud.talent_v4beta1.proto import company_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import completion_service_pb2
from google.cloud.talent_v4beta1.proto import completion_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import event_pb2
from google.cloud.talent_v4beta1.proto import event_service_pb2
from google.cloud.talent_v4beta1.proto import event_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import filters_pb2
from google.cloud.talent_v4beta1.proto import histogram_pb2
from google.cloud.talent_v4beta1.proto import job_pb2
from google.cloud.talent_v4beta1.proto import job_service_pb2
from google.cloud.talent_v4beta1.proto import job_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import profile_pb2
from google.cloud.talent_v4beta1.proto import profile_service_pb2
from google.cloud.talent_v4beta1.proto import profile_service_pb2_grpc
from google.longrunning import operations_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2


_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("google-cloud-talent").version


class ProfileServiceClient(object):
    """
    A service that handles profile management, including profile CRUD,
    enumeration and search.
    """

    SERVICE_ADDRESS = "jobs.googleapis.com:443"
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = "google.cloud.talent.v4beta1.ProfileService"

    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            ProfileServiceClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(filename)
        kwargs["credentials"] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    @classmethod
    def profile_path(cls, project, tenant, profile):
        """Return a fully-qualified profile string."""
        return google.api_core.path_template.expand(
            "projects/{project}/tenants/{tenant}/profiles/{profile}",
            project=project,
            tenant=tenant,
            profile=profile,
        )

    @classmethod
    def tenant_path(cls, project, tenant):
        """Return a fully-qualified tenant string."""
        return google.api_core.path_template.expand(
            "projects/{project}/tenants/{tenant}", project=project, tenant=tenant
        )

    def __init__(
        self,
        transport=None,
        channel=None,
        credentials=None,
        client_config=None,
        client_info=None,
        client_options=None,
    ):
        """Constructor.

        Args:
            transport (Union[~.ProfileServiceGrpcTransport,
                    Callable[[~.Credentials, type], ~.ProfileServiceGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            client_options (Union[dict, google.api_core.client_options.ClientOptions]):
                Client options used to set user options on the client. API Endpoint
                should be set through client_options.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config is not None:
            warnings.warn(
                "The `client_config` argument is deprecated.",
                PendingDeprecationWarning,
                stacklevel=2,
            )
        else:
            client_config = profile_service_client_config.config

        if channel:
            warnings.warn(
                "The `channel` argument is deprecated; use " "`transport` instead.",
                PendingDeprecationWarning,
                stacklevel=2,
            )

        api_endpoint = self.SERVICE_ADDRESS
        if client_options:
            if type(client_options) == dict:
                client_options = google.api_core.client_options.from_dict(
                    client_options
                )
            if client_options.api_endpoint:
                api_endpoint = client_options.api_endpoint

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=profile_service_grpc_transport.ProfileServiceGrpcTransport,
                    address=api_endpoint,
                )
            else:
                if credentials:
                    raise ValueError(
                        "Received both a transport instance and "
                        "credentials; these are mutually exclusive."
                    )
                self.transport = transport
        else:
            self.transport = profile_service_grpc_transport.ProfileServiceGrpcTransport(
                address=api_endpoint, channel=channel, credentials=credentials
            )

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION
            )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config["interfaces"][self._INTERFACE_NAME]
        )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def list_profiles(
        self,
        parent,
        filter_=None,
        page_size=None,
        read_mask=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Lists profiles by filter. The order is unspecified.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.ProfileServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # Iterate over all results
            >>> for element in client.list_profiles(parent):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.list_profiles(parent).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): Required. The resource name of the tenant under which the profile is
                created.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenants/bar".
            filter_ (str): The filter string specifies the profiles to be enumerated.

                Supported operator: =, AND

                The field(s) eligible for filtering are:

                -  ``externalId``
                -  ``groupId``

                externalId and groupId cannot be specified at the same time. If both
                externalId and groupId are provided, the API will return a bad request
                error.

                Sample Query:

                -  externalId = "externalId-1"
                -  groupId = "groupId-1"
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            read_mask (Union[dict, ~google.cloud.talent_v4beta1.types.FieldMask]): A field mask to specify the profile fields to be listed in response. All
                fields are listed if it is unset.

                Valid values are:

                -  name

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~google.cloud.talent_v4beta1.types.Profile` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "list_profiles" not in self._inner_api_calls:
            self._inner_api_calls[
                "list_profiles"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.list_profiles,
                default_retry=self._method_configs["ListProfiles"].retry,
                default_timeout=self._method_configs["ListProfiles"].timeout,
                client_info=self._client_info,
            )

        request = profile_service_pb2.ListProfilesRequest(
            parent=parent, filter=filter_, page_size=page_size, read_mask=read_mask
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["list_profiles"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="profiles",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator

    def create_profile(
        self,
        parent,
        profile,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Creates and returns a new profile.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.ProfileServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `profile`:
            >>> profile = {}
            >>>
            >>> response = client.create_profile(parent, profile)

        Args:
            parent (str): Required. The name of the tenant this profile belongs to.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenants/bar".
            profile (Union[dict, ~google.cloud.talent_v4beta1.types.Profile]): Required. The profile to be created.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.Profile`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.talent_v4beta1.types.Profile` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "create_profile" not in self._inner_api_calls:
            self._inner_api_calls[
                "create_profile"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.create_profile,
                default_retry=self._method_configs["CreateProfile"].retry,
                default_timeout=self._method_configs["CreateProfile"].timeout,
                client_info=self._client_info,
            )

        request = profile_service_pb2.CreateProfileRequest(
            parent=parent, profile=profile
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["create_profile"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def get_profile(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Gets the specified profile.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.ProfileServiceClient()
            >>>
            >>> name = client.profile_path('[PROJECT]', '[TENANT]', '[PROFILE]')
            >>>
            >>> response = client.get_profile(name)

        Args:
            name (str): Required. Resource name of the profile to get.

                The format is
                "projects/{project\_id}/tenants/{tenant\_id}/profiles/{profile\_id}".
                For example, "projects/foo/tenants/bar/profiles/baz".
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.talent_v4beta1.types.Profile` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "get_profile" not in self._inner_api_calls:
            self._inner_api_calls[
                "get_profile"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_profile,
                default_retry=self._method_configs["GetProfile"].retry,
                default_timeout=self._method_configs["GetProfile"].timeout,
                client_info=self._client_info,
            )

        request = profile_service_pb2.GetProfileRequest(name=name)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["get_profile"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def update_profile(
        self,
        profile,
        update_mask=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Updates the specified profile and returns the updated result.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.ProfileServiceClient()
            >>>
            >>> # TODO: Initialize `profile`:
            >>> profile = {}
            >>>
            >>> response = client.update_profile(profile)

        Args:
            profile (Union[dict, ~google.cloud.talent_v4beta1.types.Profile]): Required. Profile to be updated.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.Profile`
            update_mask (Union[dict, ~google.cloud.talent_v4beta1.types.FieldMask]): A field mask to specify the profile fields to update.

                A full update is performed if it is unset.

                Valid values are:

                -  external\_id
                -  source
                -  source\_types
                -  uri
                -  is\_hirable
                -  create\_time
                -  update\_time
                -  candidate\_update\_time
                -  resume\_update\_time
                -  resume
                -  person\_names
                -  addresses
                -  email\_addresses
                -  phone\_numbers
                -  personal\_uris
                -  additional\_contact\_info
                -  employment\_records
                -  education\_records
                -  skills
                -  activities
                -  publications
                -  patents
                -  certifications
                -  recruiting\_notes
                -  custom\_attributes
                -  group\_id
                -  external\_system
                -  source\_note
                -  primary\_responsibilities
                -  citizenships
                -  work\_authorizations
                -  employee\_types
                -  language\_code
                -  qualification\_summary
                -  allowed\_contact\_types
                -  preferred\_contact\_types
                -  contact\_availability
                -  language\_fluencies
                -  work\_preference
                -  industry\_experiences
                -  work\_environment\_experiences
                -  work\_availability
                -  security\_clearances
                -  references
                -  assessments
                -  interviews

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.talent_v4beta1.types.Profile` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "update_profile" not in self._inner_api_calls:
            self._inner_api_calls[
                "update_profile"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.update_profile,
                default_retry=self._method_configs["UpdateProfile"].retry,
                default_timeout=self._method_configs["UpdateProfile"].timeout,
                client_info=self._client_info,
            )

        request = profile_service_pb2.UpdateProfileRequest(
            profile=profile, update_mask=update_mask
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("profile.name", profile.name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["update_profile"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def delete_profile(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Deletes the specified profile.
        Prerequisite: The profile has no associated applications or assignments
        associated.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.ProfileServiceClient()
            >>>
            >>> name = client.profile_path('[PROJECT]', '[TENANT]', '[PROFILE]')
            >>>
            >>> client.delete_profile(name)

        Args:
            name (str): Required. Resource name of the profile to be deleted.

                The format is
                "projects/{project\_id}/tenants/{tenant\_id}/profiles/{profile\_id}".
                For example, "projects/foo/tenants/bar/profiles/baz".
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "delete_profile" not in self._inner_api_calls:
            self._inner_api_calls[
                "delete_profile"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.delete_profile,
                default_retry=self._method_configs["DeleteProfile"].retry,
                default_timeout=self._method_configs["DeleteProfile"].timeout,
                client_info=self._client_info,
            )

        request = profile_service_pb2.DeleteProfileRequest(name=name)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        self._inner_api_calls["delete_profile"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def search_profiles(
        self,
        parent,
        request_metadata,
        profile_query=None,
        page_size=None,
        offset=None,
        disable_spell_check=None,
        order_by=None,
        case_sensitive_sort=None,
        histogram_queries=None,
        result_set_id=None,
        strict_keywords_search=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Searches for profiles within a tenant.

        For example, search by raw queries "software engineer in Mountain View"
        or search by structured filters (location filter, education filter,
        etc.).

        See ``SearchProfilesRequest`` for more information.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.ProfileServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `request_metadata`:
            >>> request_metadata = {}
            >>>
            >>> # Iterate over all results
            >>> for element in client.search_profiles(parent, request_metadata):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.search_profiles(parent, request_metadata).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): Required. The resource name of the tenant to search within.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenants/bar".
            request_metadata (Union[dict, ~google.cloud.talent_v4beta1.types.RequestMetadata]): Required. The meta information collected about the profile search user. This is used
                to improve the search quality of the service. These values are provided by
                users, and must be precise and consistent.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.RequestMetadata`
            profile_query (Union[dict, ~google.cloud.talent_v4beta1.types.ProfileQuery]): Search query to execute. See ``ProfileQuery`` for more details.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.ProfileQuery`
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            offset (int): An integer that specifies the current offset (that is, starting result)
                in search results. This field is only considered if ``page_token`` is
                unset.

                The maximum allowed value is 5000. Otherwise an error is thrown.

                For example, 0 means to search from the first profile, and 10 means to
                search from the 11th profile. This can be used for pagination, for
                example pageSize = 10 and offset = 10 means to search from the second
                page.
            disable_spell_check (bool): This flag controls the spell-check feature. If ``false``, the service
                attempts to correct a misspelled query.

                For example, "enginee" is corrected to "engineer".
            order_by (str): The criteria that determines how search results are sorted. Defaults is
                "relevance desc" if no value is specified.

                Supported options are:

                -  "relevance desc": By descending relevance, as determined by the API
                   algorithms.
                -  "update\_date desc": Sort by ``Profile.update_time`` in descending
                   order (recently updated profiles first).
                -  "create\_date desc": Sort by ``Profile.create_time`` in descending
                   order (recently created profiles first).
                -  "first\_name": Sort by ``PersonName.PersonStructuredName.given_name``
                   in ascending order.
                -  "first\_name desc": Sort by
                   ``PersonName.PersonStructuredName.given_name`` in descending order.
                -  "last\_name": Sort by ``PersonName.PersonStructuredName.family_name``
                   in ascending order.
                -  "last\_name desc": Sort by
                   ``PersonName.PersonStructuredName.family_name`` in ascending order.
            case_sensitive_sort (bool): When sort by field is based on alphabetical order, sort values case
                sensitively (based on ASCII) when the value is set to true. Default value
                is case in-sensitive sort (false).
            histogram_queries (list[Union[dict, ~google.cloud.talent_v4beta1.types.HistogramQuery]]): A list of expressions specifies histogram requests against matching
                profiles for ``SearchProfilesRequest``.

                The expression syntax looks like a function definition with parameters.

                Function syntax: function\_name(histogram\_facet[, list of buckets])

                Data types:

                -  Histogram facet: facet names with format [a-zA-Z][a-zA-Z0-9\_]+.
                -  String: string like "any string with backslash escape for quote(")."
                -  Number: whole number and floating point number like 10, -1 and -0.01.
                -  List: list of elements with comma(,) separator surrounded by square
                   brackets. For example, [1, 2, 3] and ["one", "two", "three"].

                Built-in constants:

                -  MIN (minimum number similar to java Double.MIN\_VALUE)
                -  MAX (maximum number similar to java Double.MAX\_VALUE)

                Built-in functions:

                -  bucket(start, end[, label]) Bucket build-in function creates a bucket
                   with range of \`start, end). Note that the end is exclusive. For
                   example, bucket(1, MAX, "positive number") or bucket(1, 10).

                Histogram Facets:

                -  admin1: Admin1 is a global placeholder for referring to state,
                   province, or the particular term a country uses to define the
                   geographic structure below the country level. Examples include states
                   codes such as "CA", "IL", "NY", and provinces, such as "BC".
                -  locality: Locality is a global placeholder for referring to city,
                   town, or the particular term a country uses to define the geographic
                   structure below the admin1 level. Examples include city names such as
                   "Mountain View" and "New York".
                -  extended\_locality: Extended locality is concatenated version of
                   admin1 and locality with comma separator. For example, "Mountain
                   View, CA" and "New York, NY".
                -  postal\_code: Postal code of profile which follows locale code.
                -  country: Country code (ISO-3166-1 alpha-2 code) of profile, such as
                   US, JP, GB.
                -  job\_title: Normalized job titles specified in EmploymentHistory.
                -  company\_name: Normalized company name of profiles to match on.
                -  institution: The school name. For example, "MIT", "University of
                   California, Berkeley"
                -  degree: Highest education degree in ISCED code. Each value in degree
                   covers a specific level of education, without any expansion to upper
                   nor lower levels of education degree.
                -  experience\_in\_months: experience in months. 0 means 0 month to 1
                   month (exclusive).
                -  application\_date: The application date specifies application start
                   dates. See [ApplicationDateFilter\` for more details.
                -  application\_outcome\_notes: The application outcome reason specifies
                   the reasons behind the outcome of the job application. See
                   ``ApplicationOutcomeNotesFilter`` for more details.
                -  application\_job\_title: The application job title specifies the job
                   applied for in the application. See ``ApplicationJobFilter`` for more
                   details.
                -  hirable\_status: Hirable status specifies the profile's hirable
                   status.
                -  string\_custom\_attribute: String custom attributes. Values can be
                   accessed via square bracket notation like
                   string\_custom\_attribute["key1"].
                -  numeric\_custom\_attribute: Numeric custom attributes. Values can be
                   accessed via square bracket notation like
                   numeric\_custom\_attribute["key1"].

                Example expressions:

                -  count(admin1)
                -  count(experience\_in\_months, [bucket(0, 12, "1 year"), bucket(12,
                   36, "1-3 years"), bucket(36, MAX, "3+ years")])
                -  count(string\_custom\_attribute["assigned\_recruiter"])
                -  count(numeric\_custom\_attribute["favorite\_number"], [bucket(MIN, 0,
                   "negative"), bucket(0, MAX, "non-negative")])

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.HistogramQuery`
            result_set_id (str): An id that uniquely identifies the result set of a ``SearchProfiles``
                call. The id should be retrieved from the ``SearchProfilesResponse``
                message returned from a previous invocation of ``SearchProfiles``.

                A result set is an ordered list of search results.

                If this field is not set, a new result set is computed based on the
                ``profile_query``. A new ``result_set_id`` is returned as a handle to
                access this result set.

                If this field is set, the service will ignore the resource and
                ``profile_query`` values, and simply retrieve a page of results from the
                corresponding result set. In this case, one and only one of
                ``page_token`` or ``offset`` must be set.

                A typical use case is to invoke ``SearchProfilesRequest`` without this
                field, then use the resulting ``result_set_id`` in
                ``SearchProfilesResponse`` to page through the results.
            strict_keywords_search (bool): This flag is used to indicate whether the service will attempt to
                understand synonyms and terms related to the search query or treat the
                query "as is" when it generates a set of results. By default this flag is
                set to false, thus allowing expanded results to also be returned. For
                example a search for "software engineer" might also return candidates who
                have experience in jobs similar to software engineer positions. By setting
                this flag to true, the service will only attempt to deliver candidates has
                software engineer in his/her global fields by treating "software engineer"
                as a keyword.

                It is recommended to provide a feature in the UI (such as a checkbox) to
                allow recruiters to set this flag to true if they intend to search for
                longer boolean strings.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~google.cloud.talent_v4beta1.types.SummarizedProfile` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "search_profiles" not in self._inner_api_calls:
            self._inner_api_calls[
                "search_profiles"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.search_profiles,
                default_retry=self._method_configs["SearchProfiles"].retry,
                default_timeout=self._method_configs["SearchProfiles"].timeout,
                client_info=self._client_info,
            )

        request = profile_service_pb2.SearchProfilesRequest(
            parent=parent,
            request_metadata=request_metadata,
            profile_query=profile_query,
            page_size=page_size,
            offset=offset,
            disable_spell_check=disable_spell_check,
            order_by=order_by,
            case_sensitive_sort=case_sensitive_sort,
            histogram_queries=histogram_queries,
            result_set_id=result_set_id,
            strict_keywords_search=strict_keywords_search,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["search_profiles"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="summarized_profiles",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/event.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/event.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\nEventProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n-google/cloud/talent_v4beta1/proto/event.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto"\x8c\x02\n\x0b\x43lientEvent\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x15\n\x08\x65vent_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x34\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x02\x12:\n\tjob_event\x18\x05 \x01(\x0b\x32%.google.cloud.talent.v4beta1.JobEventH\x00\x12\x42\n\rprofile_event\x18\x06 \x01(\x0b\x32).google.cloud.talent.v4beta1.ProfileEventH\x00\x12\x13\n\x0b\x65vent_notes\x18\t \x01(\tB\x07\n\x05\x65vent"\xf6\x03\n\x08JobEvent\x12\x45\n\x04type\x18\x01 \x01(\x0e\x32\x32.google.cloud.talent.v4beta1.JobEvent.JobEventTypeB\x03\xe0\x41\x02\x12\x11\n\x04jobs\x18\x02 \x03(\tB\x03\xe0\x41\x02\x12\x0f\n\x07profile\x18\x03 \x01(\t"\xfe\x02\n\x0cJobEventType\x12\x1e\n\x1aJOB_EVENT_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nIMPRESSION\x10\x01\x12\x08\n\x04VIEW\x10\x02\x12\x11\n\rVIEW_REDIRECT\x10\x03\x12\x15\n\x11\x41PPLICATION_START\x10\x04\x12\x16\n\x12\x41PPLICATION_FINISH\x10\x05\x12 \n\x1c\x41PPLICATION_QUICK_SUBMISSION\x10\x06\x12\x18\n\x14\x41PPLICATION_REDIRECT\x10\x07\x12!\n\x1d\x41PPLICATION_START_FROM_SEARCH\x10\x08\x12$\n APPLICATION_REDIRECT_FROM_SEARCH\x10\t\x12\x1e\n\x1a\x41PPLICATION_COMPANY_SUBMIT\x10\n\x12\x0c\n\x08\x42OOKMARK\x10\x0b\x12\x10\n\x0cNOTIFICATION\x10\x0c\x12\t\n\x05HIRED\x10\r\x12\x0b\n\x07SENT_CV\x10\x0e\x12\x15\n\x11INTERVIEW_GRANTED\x10\x0f"\xe2\x01\n\x0cProfileEvent\x12M\n\x04type\x18\x01 \x01(\x0e\x32:.google.cloud.talent.v4beta1.ProfileEvent.ProfileEventTypeB\x03\xe0\x41\x02\x12\x15\n\x08profiles\x18\x02 \x03(\tB\x03\xe0\x41\x02\x12\x0c\n\x04jobs\x18\x06 \x03(\t"^\n\x10ProfileEventType\x12"\n\x1ePROFILE_EVENT_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nIMPRESSION\x10\x01\x12\x08\n\x04VIEW\x10\x02\x12\x0c\n\x08\x42OOKMARK\x10\x03\x42x\n\x1f\x63om.google.cloud.talent.v4beta1B\nEventProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_JOBEVENT_JOBEVENTTYPE = _descriptor.EnumDescriptor(
    name="JobEventType",
    full_name="google.cloud.talent.v4beta1.JobEvent.JobEventType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="JOB_EVENT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMPRESSION", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VIEW", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VIEW_REDIRECT", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_START",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_FINISH",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_QUICK_SUBMISSION",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_REDIRECT",
            index=7,
            number=7,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_START_FROM_SEARCH",
            index=8,
            number=8,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_REDIRECT_FROM_SEARCH",
            index=9,
            number=9,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_COMPANY_SUBMIT",
            index=10,
            number=10,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="BOOKMARK", index=11, number=11, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="NOTIFICATION", index=12, number=12, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="HIRED", index=13, number=13, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SENT_CV", index=14, number=14, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="INTERVIEW_GRANTED",
            index=15,
            number=15,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=566,
    serialized_end=948,
)
_sym_db.RegisterEnumDescriptor(_JOBEVENT_JOBEVENTTYPE)

_PROFILEEVENT_PROFILEEVENTTYPE = _descriptor.EnumDescriptor(
    name="ProfileEventType",
    full_name="google.cloud.talent.v4beta1.ProfileEvent.ProfileEventType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="PROFILE_EVENT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMPRESSION", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VIEW", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BOOKMARK", index=3, number=3, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1083,
    serialized_end=1177,
)
_sym_db.RegisterEnumDescriptor(_PROFILEEVENT_PROFILEEVENTTYPE)


_CLIENTEVENT = _descriptor.Descriptor(
    name="ClientEvent",
    full_name="google.cloud.talent.v4beta1.ClientEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="request_id",
            full_name="google.cloud.talent.v4beta1.ClientEvent.request_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="event_id",
            full_name="google.cloud.talent.v4beta1.ClientEvent.event_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="google.cloud.talent.v4beta1.ClientEvent.create_time",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_event",
            full_name="google.cloud.talent.v4beta1.ClientEvent.job_event",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="profile_event",
            full_name="google.cloud.talent.v4beta1.ClientEvent.profile_event",
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="event_notes",
            full_name="google.cloud.talent.v4beta1.ClientEvent.event_notes",
            index=5,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="event",
            full_name="google.cloud.talent.v4beta1.ClientEvent.event",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=175,
    serialized_end=443,
)


_JOBEVENT = _descriptor.Descriptor(
    name="JobEvent",
    full_name="google.cloud.talent.v4beta1.JobEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.talent.v4beta1.JobEvent.type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="jobs",
            full_name="google.cloud.talent.v4beta1.JobEvent.jobs",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="profile",
            full_name="google.cloud.talent.v4beta1.JobEvent.profile",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_JOBEVENT_JOBEVENTTYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=446,
    serialized_end=948,
)


_PROFILEEVENT = _descriptor.Descriptor(
    name="ProfileEvent",
    full_name="google.cloud.talent.v4beta1.ProfileEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.talent.v4beta1.ProfileEvent.type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="profiles",
            full_name="google.cloud.talent.v4beta1.ProfileEvent.profiles",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="jobs",
            full_name="google.cloud.talent.v4beta1.ProfileEvent.jobs",
            index=2,
            number=6,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_PROFILEEVENT_PROFILEEVENTTYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=951,
    serialized_end=1177,
)

_CLIENTEVENT.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLIENTEVENT.fields_by_name["job_event"].message_type = _JOBEVENT
_CLIENTEVENT.fields_by_name["profile_event"].message_type = _PROFILEEVENT
_CLIENTEVENT.oneofs_by_name["event"].fields.append(
    _CLIENTEVENT.fields_by_name["job_event"]
)
_CLIENTEVENT.fields_by_name["job_event"].containing_oneof = _CLIENTEVENT.oneofs_by_name[
    "event"
]
_CLIENTEVENT.oneofs_by_name["event"].fields.append(
    _CLIENTEVENT.fields_by_name["profile_event"]
)
_CLIENTEVENT.fields_by_name[
    "profile_event"
].containing_oneof = _CLIENTEVENT.oneofs_by_name["event"]
_JOBEVENT.fields_by_name["type"].enum_type = _JOBEVENT_JOBEVENTTYPE
_JOBEVENT_JOBEVENTTYPE.containing_type = _JOBEVENT
_PROFILEEVENT.fields_by_name["type"].enum_type = _PROFILEEVENT_PROFILEEVENTTYPE
_PROFILEEVENT_PROFILEEVENTTYPE.containing_type = _PROFILEEVENT
DESCRIPTOR.message_types_by_name["ClientEvent"] = _CLIENTEVENT
DESCRIPTOR.message_types_by_name["JobEvent"] = _JOBEVENT
DESCRIPTOR.message_types_by_name["ProfileEvent"] = _PROFILEEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientEvent = _reflection.GeneratedProtocolMessageType(
    "ClientEvent",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CLIENTEVENT,
        __module__="google.cloud.talent_v4beta1.proto.event_pb2",
        __doc__="""An event issued when an end user interacts with the
  application that implements Cloud Talent Solution. Providing this
  information improves the quality of results for the API clients,
  enabling the service to perform optimally. The number of events sent
  must be consistent with other calls, such as job searches, issued to the
  service by the client.
  
  
  Attributes:
      request_id:
          Strongly recommended for the best service experience.  A
          unique ID generated in the API responses. It can be found in [
          ResponseMetadata.request\_id][google.cloud.talent.v4beta1.Resp
          onseMetadata.request\_id].
      event_id:
          Required. A unique identifier, generated by the client
          application.
      create_time:
          Required. The timestamp of the event.
      event:
          Required.  The detail information of a specific event type.
      job_event:
          An event issued when a job seeker interacts with the
          application that implements Cloud Talent Solution.
      profile_event:
          An event issued when a profile searcher interacts with the
          application that implements Cloud Talent Solution.
      event_notes:
          Notes about the event provided by recruiters or other users,
          for example, feedback on why a profile was bookmarked.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ClientEvent)
    ),
)
_sym_db.RegisterMessage(ClientEvent)

JobEvent = _reflection.GeneratedProtocolMessageType(
    "JobEvent",
    (_message.Message,),
    dict(
        DESCRIPTOR=_JOBEVENT,
        __module__="google.cloud.talent_v4beta1.proto.event_pb2",
        __doc__="""An event issued when a job seeker interacts with the
  application that implements Cloud Talent Solution.
  
  
  Attributes:
      type:
          Required. The type of the event (see [JobEventType][google.clo
          ud.talent.v4beta1.JobEvent.JobEventType]).
      jobs:
          Required. The [job
          name(s)][google.cloud.talent.v4beta1.Job.name] associated with
          this event. For example, if this is an [impression][google.clo
          ud.talent.v4beta1.JobEvent.JobEventType.IMPRESSION] event,
          this field contains the identifiers of all jobs shown to the
          job seeker. If this was a
          [view][google.cloud.talent.v4beta1.JobEvent.JobEventType.VIEW]
          event, this field contains the identifier of the viewed job.
          The format is
          "projects/{project\_id}/tenants/{tenant\_id}/jobs/{job\_id}",
          for example, "projects/foo/tenants/bar/jobs/baz".
      profile:
          The [profile name][google.cloud.talent.v4beta1.Profile.name]
          associated with this client event.  The format is "projects/{p
          roject\_id}/tenants/{tenant\_id}/profiles/{profile\_id}", for
          example, "projects/foo/tenants/bar/profiles/baz".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.JobEvent)
    ),
)
_sym_db.RegisterMessage(JobEvent)

ProfileEvent = _reflection.GeneratedProtocolMessageType(
    "ProfileEvent",
    (_message.Message,),
    dict(
        DESCRIPTOR=_PROFILEEVENT,
        __module__="google.cloud.talent_v4beta1.proto.event_pb2",
        __doc__="""An event issued when a profile searcher interacts with the
  application that implements Cloud Talent Solution.
  
  
  Attributes:
      type:
          Required. Type of event.
      profiles:
          Required. The [profile
          name(s)][google.cloud.talent.v4beta1.Profile.name] associated
          with this client event.  The format is "projects/{project\_id}
          /tenants/{tenant\_id}/profiles/{profile\_id}", for example,
          "projects/foo/tenants/bar/profiles/baz".
      jobs:
          The [job name(s)][google.cloud.talent.v4beta1.Job.name]
          associated with this client event. Leave it empty if the event
          isn't associated with a job.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}/jobs/{job\_id}",
          for example, "projects/foo/tenants/bar/jobs/baz".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ProfileEvent)
    ),
)
_sym_db.RegisterMessage(ProfileEvent)


DESCRIPTOR._options = None
_CLIENTEVENT.fields_by_name["event_id"]._options = None
_CLIENTEVENT.fields_by_name["create_time"]._options = None
_JOBEVENT.fields_by_name["type"]._options = None
_JOBEVENT.fields_by_name["jobs"]._options = None
_PROFILEEVENT.fields_by_name["type"]._options = None
_PROFILEEVENT.fields_by_name["profiles"]._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.talent_v4beta1.proto import (
    completion_service_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_completion__service__pb2,
)


class CompletionStub(object):
    """A service handles auto completion.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CompleteQuery = channel.unary_unary(
            "/google.cloud.talent.v4beta1.Completion/CompleteQuery",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_completion__service__pb2.CompleteQueryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_completion__service__pb2.CompleteQueryResponse.FromString,
        )


class CompletionServicer(object):
    """A service handles auto completion.
  """

    def CompleteQuery(self, request, context):
        """Completes the specified prefix with keyword suggestions.
    Intended for use by a job search auto-complete search box.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CompletionServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CompleteQuery": grpc.unary_unary_rpc_method_handler(
            servicer.CompleteQuery,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_completion__service__pb2.CompleteQueryRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_completion__service__pb2.CompleteQueryResponse.SerializeToString,
        )
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.talent.v4beta1.Completion", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
